@@ -42,6 +42,7 @@ enum connman_device_type {
 	CONNMAN_DEVICE_TYPE_WIMAX     = 3,
 	CONNMAN_DEVICE_TYPE_BLUETOOTH = 4,
 	CONNMAN_DEVICE_TYPE_GPS       = 5,
+	CONNMAN_DEVICE_TYPE_MBM       = 14,
 	CONNMAN_DEVICE_TYPE_HSO       = 15,
 	CONNMAN_DEVICE_TYPE_NOZOMI    = 16,
 	CONNMAN_DEVICE_TYPE_HUAWEI    = 17,
@@ -90,6 +91,7 @@ int connman_device_set_scanning(struct connman_device *device,
 						connman_bool_t scanning);
 int connman_device_set_disconnected(struct connman_device *device,
 						connman_bool_t disconnected);
+connman_bool_t connman_device_get_disconnected(struct connman_device *device);
 int connman_device_set_connected(struct connman_device *device,
 						connman_bool_t connected);
 
